@@ -524,6 +524,9 @@ export class ReporterService {
     reportFolder: IdlObject = null;
     outputFolder: IdlObject = null;
 
+    globalCanShare: boolean = false;
+    topPermOrg = { RUN_REPORTS: -1, SHARE_REPORT_FOLDER: -1, VIEW_REPORT_OUTPUT: -1 };
+
     constructor (
         private evt: EventService,
         private auth: AuthService,
@@ -769,7 +772,20 @@ export class ReporterService {
             }))
         };
 
+        const perm_list = [ 'RUN_REPORTS', 'SHARE_REPORT_FOLDER', 'VIEW_REPORT_OUTPUT' ];
         return Promise.all([
+            new Promise<void>((resolve, reject) => {
+                this.net.request(
+                    'open-ils.actor',
+                    'open-ils.actor.user.perm.highest_org.batch',
+                    this.auth.token(), this.auth.user().id(), perm_list
+                ).toPromise()
+                .then(permset => {
+                    permset.forEach((perm_org,ind) => this.topPermOrg[perm_list[ind]] = perm_org);
+                    if (this.topPermOrg.SHARE_REPORT_FOLDER > -1) this.globalCanShare = true;
+                    resolve();
+                });
+            }),
             new Promise<void>((resolve, reject) => {
                 this.net.request(
                     'open-ils.reporter',
@@ -940,13 +956,6 @@ export class ReporterService {
     }
 
     _initSRFolders(): Promise<any[]> {
-        if (this.templateFolder &&
-            this.reportFolder &&
-            this.outputFolder
-        ) {
-            return Promise.resolve([]);
-        }
-
         return Promise.all([
             new Promise<void>((resolve, reject) => {
                 // Verify folders exist, create if not
@@ -1181,7 +1190,7 @@ export class ReporterService {
         templ.filterFields.forEach((el, idx) => {
             if (isSimple || !el.with_value_input) {
                 rrData[el.filter_placeholder] = el.force_filtervalues ? el.force_filtervalues : el.filter_value;
-                if (el.datatype === 'org_unit' && el.operator.name === '= any') { // special case for org selector
+                if (typeof rrData[el.filter_placeholder] === 'string' && el.datatype === 'org_unit' && el.operator.name === '= any') { // special case for org selector
                     const final_value = { transform: 'Bare', params: rrData[el.filter_placeholder] };
                     final_value['_org_family_primaryOrgId'] = el._org_family_primaryOrgId;
                     final_value['_org_family_includeAncestors'] = el._org_family_includeAncestors;
@@ -1380,6 +1389,7 @@ export class ReporterService {
         templ: SRTemplate,
         isSimple = false
     ) {
+        const self = this;
         const fmClass = templ.fmClass;
         const localClasses = this.idl.classes;
         const sourceClass = localClasses[fmClass];
@@ -1506,8 +1516,7 @@ export class ReporterService {
         	let pathHash = '';
     	    treeNodeList.forEach((n,i) => {
 	            if (i) {
-            	    pathHash += ' -> ';
-	            	if (n.stateFlag) {pathHash += ' [Required]';}
+            	    pathHash += ' -> [Join Type: ' + self.pickJoinTypeFromTreeNodeStateFlag(n.stateFlag) + ']';
         	    }
 	            if (n.callerData.fmField?.name) {
 	                pathHash += n.callerData.fmField.name + '.';
@@ -1537,14 +1546,14 @@ export class ReporterService {
                     from_branch['join'] ??= {};
                     if (!from_branch['join'][new_join_path_key]) {
                         from_branch['join'][new_join_path_key] = {
-                            type: (step.stateFlag ? 'inner' : 'left'),
+                            type: self.pickJoinTypeFromTreeNodeStateFlag(step.stateFlag),
                             key: step.callerData.fmField.key,
                             alias: step_hash,
                             idlclass: step.callerData.fmField.class,
                             label: el.path_label,
                             table:  step_table.source ?? step_table.table
                         };
-                        console.log('adding '+(step.stateFlag ? 'inner' : 'left')+'-join branch for path key: ' + new_join_path_key);
+                        console.log('adding '+from_branch['join'][new_join_path_key]['type']+'-join branch for path key: ' + new_join_path_key);
                     }
 
                     reportTemplate.relations[step_hash] = from_branch['join'][new_join_path_key];
@@ -1557,7 +1566,22 @@ export class ReporterService {
 
     }
 
+    pickJoinTypeFromTreeNodeStateFlag = function(flag: boolean) {
+        if (flag === null) {
+            return 'right';
+        }
+        return flag ? 'inner' : 'left';
+    }
+
+    pickTreeNodeStateFlagFromJoinType = function(type: string) {
+        if (type === 'right') {
+            return null;
+        }
+        return type === 'inner' ? true : false;
+    }
+
     upgradeAngJSTemplateData = function(template: IdlObject) {
+        const self = this;
         const localIdl = this.idl;
 
         const newSRTempl = new SRTemplate();
@@ -1650,7 +1674,7 @@ export class ReporterService {
             oldCol.path.forEach((old,ind) => {
                 const newPathNode = {
                     label: old.label,
-                    stateFlag: (old.jtype === 'inner') ? true : false,
+                    stateFlag: self.pickTreeNodeStateFlagFromJoinType(old.jtype),
                     callerData: { fmClass: old.classname }
                 };
                 if (old.uplink) {
@@ -1678,8 +1702,7 @@ export class ReporterService {
         	let pathHash = '';
     	    treeNodeList.forEach((n,i) => {
 	            if (i) {
-            	    pathHash += ' -> ';
-	            	if (n.stateFlag) {pathHash += ' [Required]';}
+            	    pathHash += ' -> [Join Type: ' + self.pickJoinTypeFromTreeNodeStateFlag(n.stateFlag) + ']';
         	    }
     	        pathHash += n.callerData.fmClass;
         	});
